Computes maximum likelihood estimators (MLE) for finite mixtures of unrestricted multivariate skew t (FM-MST) model via the EM algorithm.
fmmst(g = 1, dat, initial = NULL, known = NULL, itmax = 100,
eps = 1e-03, clust=NULL, nkmeans=20, print = T)
# S3 method for fmmst
summary(object, ...)
# S3 method for fmmst
print(x, ...)an object class of class "fmmst", i.e. a fitted model.
a scalar specifying the number of components in the mixture model
the data matrix giving the coordinates of the point(s) where the density is evaluated.
This is either a vector of length p or a matrix with p columns.
(optional) a list containing the initial parameters of the mixture model.
See the 'Details' section. The default is NULL.
(optional) a list containing parameters of the mixture model that are known
and not required to be estimated. See the 'Details' section. The default is NULL.
(optional) a positive integer specifying the maximum number of EM iterations
to perform. The default is 100.
(optional) a numeric value used to control the termination criteria for the EM loops.
It is the maximum tolerance for the absolute difference between the log-likelihood value
and the asymptotic log likelihood value. The default is 1e-6.
(optional) a numeric value of length nrow(dat) containing the
initial labels for each data point in dat. The default is NULL,
indicating no initial clustering is known.
(optional) a numeric value indicating how many k-means trials to be used
when searching for initial values. The default is 20.
(optional) a logical value. If TRUE, output for each iteration will be printed out.
if FALSE, no output is printed. The default is TRUE. See the 'Details' section.
not used.
a list of g numeric matrices containing the location parameter for each component.
a list of g numeric matrices containing the scale parameter for each component.
a list of g numeric matrices containing the skewness parameter for each component.
a numeric vector of length g representing the degrees of freedom for each component.
a vector of length of g specifying the mixing proportions for each component.
an g by n matrix of posterior probability of component membership.
a vector of length n of final partition.
the final log likelihood value.
a vector of log likelihood values at each EM iteration.
number of iterations performed.
the final absolute difference between the log likelihood value and the asymptotic log likelihood value.
Akaike Information Criterion (AIC), Bayes Information Criterion (BIC)
The arguments init and known, if specified, is a list structure containing
at least one of mu, sigma, delta, dof, pro.
If init=FALSE (default), the program uses an automatic approach based on
k-means clustering to generate an initial value for the model parameters.
Note that this may not provide the best results.
Lee S, McLachlan G (2011). On the fitting of mixtures of multivariate skew t-distributions via the EM algorithm. arXiv:1109.4706 [stat.ME]
Lee, S. and McLachlan, G.J. (2014) Finite mixtures of multivariate skew t-distributions: some recent and new results. Statistics and Computing, 24, 181-202.
Lee, S. and McLachlan, G.J. (2013) EMMIXuskew: An R package for
fitting mixtures of multivariate skew t-distributions via the EM algorithm.
Journal of Statistical Software, 55(12), 1-22.
URL http://www.jstatsoft.org/v55/i12/.
# NOT RUN {
#a short demo using geyser data
library(MASS)
Fit <- fmmst(3, geyser)
summary(Fit)
print(Fit)
# }
Run the code above in your browser using DataLab